@@ -1,13 +1,14 @@
 package cli
 
 import (
+	"errors"
 	"fmt"
-	"os"
 	"path/filepath"
 	"strings"
 
 	"github.com/jandedobbeleer/oh-my-posh/src/config"
-	"github.com/jandedobbeleer/oh-my-posh/src/runtime"
+	"github.com/jandedobbeleer/oh-my-posh/src/runtime/path"
+	"github.com/jandedobbeleer/oh-my-posh/src/shell"
 
 	"github.com/spf13/cobra"
 )
@@ -36,19 +37,14 @@ Exports the current config to "~/new_config.omp.json" (in JSON format).`,
 		if len(output) == 0 && len(format) == 0 {
 			// usage error
 			fmt.Println("neither output path nor export format is specified")
-			os.Exit(2)
+			exitcode = 2
+			return
 		}
 
-		env := &runtime.Terminal{
-			CmdFlags: &runtime.Flags{
-				Config: configFlag,
-			},
-		}
-		env.Init()
-		defer env.Close()
-		cfg := config.Load(env)
+		configFile := config.Path(configFlag)
+		cfg, _ := config.Load(configFile, shell.GENERIC, false)
 
-		validateExportFormat := func() {
+		validateExportFormat := func() error {
 			format = strings.ToLower(format)
 			switch format {
 			case "json", "jsonc":
@@ -61,12 +57,17 @@ Exports the current config to "~/new_config.omp.json" (in JSON format).`,
 				formats := []string{"json", "jsonc", "toml", "tml", "yaml", "yml"}
 				// usage error
 				fmt.Printf("export format must be one of these: %s\n", strings.Join(formats, ", "))
-				os.Exit(2)
+				exitcode = 2
+				return errors.New("invalide export format")
 			}
+
+			return nil
 		}
 
 		if len(format) != 0 {
-			validateExportFormat()
+			if err := validateExportFormat(); err != nil {
+				return
+			}
 		}
 
 		if len(output) == 0 {
@@ -74,27 +75,29 @@ Exports the current config to "~/new_config.omp.json" (in JSON format).`,
 			return
 		}
 
-		cfg.Output = cleanOutputPath(output, env)
+		cfg.Output = cleanOutputPath(output)
 
 		if len(format) == 0 {
 			format = strings.TrimPrefix(filepath.Ext(output), ".")
-			validateExportFormat()
+			if err := validateExportFormat(); err != nil {
+				return
+			}
 		}
 
 		cfg.Write(format)
 	},
 }
 
-func cleanOutputPath(path string, env runtime.Environment) string {
-	path = runtime.ReplaceTildePrefixWithHomeDir(env, path)
+func cleanOutputPath(output string) string {
+	output = path.ReplaceTildePrefixWithHomeDir(output)
 
-	if !filepath.IsAbs(path) {
-		if absPath, err := filepath.Abs(path); err == nil {
-			path = absPath
+	if !filepath.IsAbs(output) {
+		if absPath, err := filepath.Abs(output); err == nil {
+			output = absPath
 		}
 	}
 
-	return filepath.Clean(path)
+	return filepath.Clean(output)
 }
 
 func init() {
