@@ -17,7 +17,7 @@ import (
 	"github.com/spf13/cobra"
 )
 
-// debugCmd represents the prompt command
+// debugCmd represents the debug command
 var debugCmd = createDebugCmd()
 
 func init() {
@@ -32,13 +32,12 @@ func createDebugCmd() *cobra.Command {
 		Run: func(_ *cobra.Command, _ []string) {
 			startTime := time.Now()
 
-			log.Enable()
-			log.Debug("debug mode enabled")
+			log.Enable(plain)
 
 			sh := os.Getenv("POSH_SHELL")
 
 			configFile := config.Path(configFlag)
-			cfg := config.Load(configFile, sh, false)
+			cfg, _ := config.Load(configFile, sh, false)
 
 			flags := &runtime.Flags{
 				Config: configFile,
