@@ -1,14 +1,18 @@
 package config
 
 import (
+	"slices"
+	"strings"
+
+	"github.com/jandedobbeleer/oh-my-posh/src/cli/upgrade"
 	"github.com/jandedobbeleer/oh-my-posh/src/color"
 	"github.com/jandedobbeleer/oh-my-posh/src/log"
+	"github.com/jandedobbeleer/oh-my-posh/src/maps"
 	"github.com/jandedobbeleer/oh-my-posh/src/runtime"
 	"github.com/jandedobbeleer/oh-my-posh/src/segments"
 	"github.com/jandedobbeleer/oh-my-posh/src/shell"
 	"github.com/jandedobbeleer/oh-my-posh/src/template"
 	"github.com/jandedobbeleer/oh-my-posh/src/terminal"
-	"github.com/jandedobbeleer/oh-my-posh/src/upgrade"
 )
 
 const (
@@ -22,6 +26,17 @@ const (
 	Version = 3
 )
 
+type Action string
+
+func (a Action) IsDefault() bool {
+	return a != Prepend && a != Extend
+}
+
+const (
+	Prepend Action = "prepend"
+	Extend  Action = "extend"
+)
+
 // Config holds all the theme for rendering the prompt
 type Config struct {
 	Palette                 color.Palette   `json:"palette,omitempty" toml:"palette,omitempty" yaml:"palette,omitempty"`
@@ -32,27 +47,30 @@ type Config struct {
 	SecondaryPrompt         *Segment        `json:"secondary_prompt,omitempty" toml:"secondary_prompt,omitempty" yaml:"secondary_prompt,omitempty"`
 	TransientPrompt         *Segment        `json:"transient_prompt,omitempty" toml:"transient_prompt,omitempty" yaml:"transient_prompt,omitempty"`
 	ErrorLine               *Segment        `json:"error_line,omitempty" toml:"error_line,omitempty" yaml:"error_line,omitempty"`
-	TerminalBackground      color.Ansi      `json:"terminal_background,omitempty" toml:"terminal_background,omitempty" yaml:"terminal_background,omitempty"`
+	Maps                    *maps.Config    `json:"maps,omitempty" toml:"maps,omitempty" yaml:"maps,omitempty"`
+	Upgrade                 *upgrade.Config `json:"upgrade,omitempty" toml:"upgrade,omitempty" yaml:"upgrade,omitempty"`
+	Format                  string          `json:"-" toml:"-" yaml:"-"`
+	AccentColor             color.Ansi      `json:"accent_color,omitempty" toml:"accent_color,omitempty" yaml:"accent_color,omitempty"`
+	Output                  string          `json:"-" toml:"-" yaml:"-"`
+	ConsoleTitleTemplate    string          `json:"console_title_template,omitempty" toml:"console_title_template,omitempty" yaml:"console_title_template,omitempty"`
+	PWD                     string          `json:"pwd,omitempty" toml:"pwd,omitempty" yaml:"pwd,omitempty"`
 	origin                  string
-	PWD                     string                 `json:"pwd,omitempty" toml:"pwd,omitempty" yaml:"pwd,omitempty"`
-	AccentColor             color.Ansi             `json:"accent_color,omitempty" toml:"accent_color,omitempty" yaml:"accent_color,omitempty"`
-	Output                  string                 `json:"-" toml:"-" yaml:"-"`
-	ConsoleTitleTemplate    string                 `json:"console_title_template,omitempty" toml:"console_title_template,omitempty" yaml:"console_title_template,omitempty"`
-	Format                  string                 `json:"-" toml:"-" yaml:"-"`
-	Upgrade                 *upgrade.Config        `json:"upgrade,omitempty" toml:"upgrade,omitempty" yaml:"upgrade,omitempty"`
-	Cycle                   color.Cycle            `json:"cycle,omitempty" toml:"cycle,omitempty" yaml:"cycle,omitempty"`
-	ITermFeatures           terminal.ITermFeatures `json:"iterm_features,omitempty" toml:"iterm_features,omitempty" yaml:"iterm_features,omitempty"`
-	Blocks                  []*Block               `json:"blocks,omitempty" toml:"blocks,omitempty" yaml:"blocks,omitempty"`
+	TerminalBackground      color.Ansi             `json:"terminal_background,omitempty" toml:"terminal_background,omitempty" yaml:"terminal_background,omitempty"`
 	Tooltips                []*Segment             `json:"tooltips,omitempty" toml:"tooltips,omitempty" yaml:"tooltips,omitempty"`
+	ToolTipsAction          Action                 `json:"tooltips_action,omitempty" toml:"tooltips_action,omitempty" yaml:"tooltips_action,omitempty"`
+	Blocks                  []*Block               `json:"blocks,omitempty" toml:"blocks,omitempty" yaml:"blocks,omitempty"`
+	ITermFeatures           terminal.ITermFeatures `json:"iterm_features,omitempty" toml:"iterm_features,omitempty" yaml:"iterm_features,omitempty"`
+	Cycle                   color.Cycle            `json:"cycle,omitempty" toml:"cycle,omitempty" yaml:"cycle,omitempty"`
 	Version                 int                    `json:"version" toml:"version" yaml:"version"`
 	AutoUpgrade             bool                   `json:"-" toml:"-" yaml:"-"`
 	ShellIntegration        bool                   `json:"shell_integration,omitempty" toml:"shell_integration,omitempty" yaml:"shell_integration,omitempty"`
 	MigrateGlyphs           bool                   `json:"-" toml:"-" yaml:"-"`
 	PatchPwshBleed          bool                   `json:"patch_pwsh_bleed,omitempty" toml:"patch_pwsh_bleed,omitempty" yaml:"patch_pwsh_bleed,omitempty"`
 	EnableCursorPositioning bool                   `json:"enable_cursor_positioning,omitempty" toml:"enable_cursor_positioning,omitempty" yaml:"enable_cursor_positioning,omitempty"`
+	Async                   bool                   `json:"async,omitempty" toml:"async,omitempty" yaml:"async,omitempty"`
+	FinalSpace              bool                   `json:"final_space,omitempty" toml:"final_space,omitempty" yaml:"final_space,omitempty"`
+	UpgradeNotice           bool                   `json:"-" toml:"-" yaml:"-"`
 	updated                 bool
-	FinalSpace              bool `json:"final_space,omitempty" toml:"final_space,omitempty" yaml:"final_space,omitempty"`
-	UpgradeNotice           bool `json:"-" toml:"-" yaml:"-"`
 }
 
 func (cfg *Config) MakeColors(env runtime.Environment) color.String {
@@ -93,6 +111,13 @@ func (cfg *Config) getPalette() color.Palette {
 func (cfg *Config) Features(env runtime.Environment) shell.Features {
 	var feats shell.Features
 
+	asyncShells := []string{shell.BASH, shell.ZSH, shell.FISH, shell.PWSH, shell.PWSH5}
+
+	if cfg.Async && slices.Contains(asyncShells, env.Shell()) {
+		log.Debug("async enabled")
+		feats = append(feats, shell.Async)
+	}
+
 	if cfg.TransientPrompt != nil {
 		log.Debug("transient prompt enabled")
 		feats = append(feats, shell.Transient)
@@ -103,7 +128,10 @@ func (cfg *Config) Features(env runtime.Environment) shell.Features {
 		feats = append(feats, shell.FTCSMarks)
 	}
 
-	feats = append(feats, cfg.UpgradeFeatures(env)...)
+	// do not enable upgrade features when async is enabled
+	if !slices.Contains(feats, shell.Async) {
+		feats = append(feats, cfg.upgradeFeatures(env)...)
+	}
 
 	if cfg.ErrorLine != nil || cfg.ValidLine != nil {
 		log.Debug("error or valid line enabled")
@@ -134,7 +162,7 @@ func (cfg *Config) Features(env runtime.Environment) shell.Features {
 		for _, segment := range block.Segments {
 			if segment.Type == AZ {
 				source := segment.Properties.GetString(segments.Source, segments.FirstMatch)
-				if source == segments.Pwsh || source == segments.FirstMatch {
+				if strings.Contains(source, segments.Pwsh) {
 					log.Debug("azure enabled")
 					feats = append(feats, shell.Azure)
 				}
@@ -153,7 +181,7 @@ func (cfg *Config) Features(env runtime.Environment) shell.Features {
 	return feats
 }
 
-func (cfg *Config) UpgradeFeatures(env runtime.Environment) shell.Features {
+func (cfg *Config) upgradeFeatures(env runtime.Environment) shell.Features {
 	feats := shell.Features{}
 
 	if _, OK := env.Cache().Get(upgrade.CACHEKEY); OK && !cfg.Upgrade.Force {
