@@ -72,7 +72,7 @@ func (term *Terminal) IsWsl2() bool {
 
 func (term *Terminal) IsCygwin() bool {
 	defer log.Trace(time.Now())
-	return len(term.Getenv("OSTYPE")) > 0
+	return len(term.Getenv("OSTYPE")) != 0 || term.Getenv("BROWSER") == "cygstart"
 }
 
 func (term *Terminal) TerminalWidth() (int, error) {
