@@ -171,8 +171,9 @@ func (g *Git) Template() string {
 }
 
 func (g *Git) Enabled() bool {
-	// g.command = GITCOMMAND
 	g.User = &User{}
+	g.Working = &GitStatus{}
+	g.Staging = &GitStatus{}
 
 	if !g.shouldDisplay() {
 		return false
@@ -185,9 +186,6 @@ func (g *Git) Enabled() bool {
 
 	g.RepoName = g.repoName()
 
-	g.Working = &GitStatus{}
-	g.Staging = &GitStatus{}
-
 	if g.IsBare {
 		g.getBareRepoInfo()
 		return true
@@ -199,7 +197,7 @@ func (g *Git) Enabled() bool {
 	}
 
 	displayStatus := g.props.GetBool(FetchStatus, false)
-	if g.shouldIgnoreStatus() {
+	if displayStatus && g.shouldIgnoreStatus() {
 		displayStatus = false
 	}
 
@@ -208,7 +206,7 @@ func (g *Git) Enabled() bool {
 		g.setGitHEADContext()
 		g.setBranchStatus()
 	} else {
-		g.setPrettyHEADName()
+		g.setHEADName()
 	}
 
 	if g.props.GetBool(FetchUpstreamIcon, false) {
@@ -228,7 +226,7 @@ func (g *Git) CacheKey() (string, bool) {
 		return "", false
 	}
 
-	ref := g.FileContents(g.mainSCMDir, "HEAD")
+	ref := g.fileContent(g.mainSCMDir, "HEAD")
 	ref = strings.Replace(ref, "ref: refs/heads/", "", 1)
 
 	// Use the repo clone in the cache key so the mapped path is consistent
@@ -248,8 +246,8 @@ func (g *Git) Commit() *Commit {
 	}
 
 	commitBody := g.getGitCommandOutput("log", "-1", "--pretty=format:an:%an%nae:%ae%ncn:%cn%nce:%ce%nat:%at%nsu:%s%nha:%H%nrf:%D", "--decorate=full")
-	splitted := strings.Split(strings.TrimSpace(commitBody), "\n")
-	for _, line := range splitted {
+	splitted := strings.SplitSeq(strings.TrimSpace(commitBody), "\n")
+	for line := range splitted {
 		line = strings.TrimSpace(line)
 		if len(line) <= 3 {
 			continue
@@ -274,8 +272,8 @@ func (g *Git) Commit() *Commit {
 		case "ha:":
 			g.commit.Sha = line
 		case "rf:":
-			refs := strings.Split(line, ", ")
-			for _, ref := range refs {
+			refs := strings.SplitSeq(line, ", ")
+			for ref := range refs {
 				ref = strings.TrimSpace(ref)
 				switch {
 				case strings.HasSuffix(ref, "HEAD"):
@@ -302,7 +300,7 @@ func (g *Git) StashCount() int {
 		return g.stashCount
 	}
 
-	stashContent := g.FileContents(g.scmDir, "logs/refs/stash")
+	stashContent := g.fileContent(g.scmDir, "logs/refs/stash")
 	if stashContent == "" {
 		return 0
 	}
@@ -337,22 +335,16 @@ func (g *Git) LatestTag() string {
 }
 
 func (g *Git) shouldDisplay() bool {
-	if !g.hasCommand(GITCOMMAND) {
+	gitdir, err := g.env.HasParentFilePath(".git", true)
+	if err != nil {
 		return false
 	}
 
 	if g.props.GetBool(FetchBareInfo, false) {
-		g.repoRootDir = g.env.Pwd()
-		bare := g.getGitCommandOutput("rev-parse", "--is-bare-repository")
-		if bare == trueStr {
-			g.IsBare = true
-			g.mainSCMDir = g.repoRootDir
-			return true
-		}
+		g.IsBare = g.isBareRepo(gitdir)
 	}
 
-	gitdir, err := g.env.HasParentFilePath(".git", true)
-	if err != nil {
+	if !g.hasCommand(GITCOMMAND) {
 		return false
 	}
 
@@ -383,15 +375,42 @@ func (g *Git) setUser() {
 	g.User.Email = g.getGitCommandOutput("config", "user.email")
 }
 
-func (g *Git) getBareRepoInfo() {
-	// we can still have a pointer to a bare repo
-	if file, err := g.env.HasParentFilePath(".git", true); err == nil && !file.IsDir {
-		content := g.FileContents(file.ParentFolder, ".git")
+func (g *Git) isBareRepo(gitDir *runtime.FileInfo) bool {
+	defer log.Trace(time.Now())
+
+	if gitDir.IsDir {
+		g.mainSCMDir = gitDir.Path
+	} else {
+		content := g.fileContent(gitDir.ParentFolder, ".git")
 		dir := strings.TrimPrefix(content, "gitdir: ")
-		g.mainSCMDir = filepath.Join(file.ParentFolder, dir)
+		g.mainSCMDir = filepath.Join(gitDir.ParentFolder, dir)
 	}
 
-	head := g.FileContents(g.mainSCMDir, "HEAD")
+	configData := g.fileContent(g.mainSCMDir, "config")
+	if len(configData) == 0 {
+		log.Debug("Git config file not found, not a bare repo")
+		return false
+	}
+
+	cfg, err := ini.Load([]byte(configData))
+	if err != nil {
+		log.Error(err)
+		return false
+	}
+
+	coreSection := cfg.Section("core")
+	if coreSection == nil {
+		log.Debug("Git core section not found, not a bare repo")
+		return false
+	}
+
+	bare := coreSection.Key("bare").String()
+
+	return bare == trueStr
+}
+
+func (g *Git) getBareRepoInfo() {
+	head := g.fileContent(g.mainSCMDir, "HEAD")
 	branchIcon := g.props.GetString(BranchIcon, "\uE0A0")
 	g.Ref = strings.Replace(head, "ref: refs/heads/", "", 1)
 	g.HEAD = fmt.Sprintf("%s%s", branchIcon, g.formatBranch(g.Ref))
@@ -430,35 +449,24 @@ func (g *Git) hasWorktree(gitdir *runtime.FileInfo) bool {
 	// to the mounted path
 	g.mainSCMDir = g.convertToLinuxPath(matches["dir"])
 
-	// if we don't do this, we will identify the submodule as a worktree
-	isSubmodule := strings.Contains(g.mainSCMDir, "/modules/")
-
 	// in worktrees, the path looks like this: gitdir: path/.git/worktrees/branch
 	// scmDir needs to become path/.git
 	// repoRootDir needs to become path
-	ind := strings.LastIndex(g.mainSCMDir, "/worktrees/")
-	if ind > -1 && !isSubmodule {
-		gitDir := filepath.Join(g.mainSCMDir, "gitdir")
-		g.scmDir = g.mainSCMDir[:ind]
-		gitDirContent := g.env.FileContent(gitDir)
-		g.repoRootDir = strings.TrimSuffix(gitDirContent, ".git\n")
-		g.IsWorkTree = true
-		return true
-	}
+	worktreeIndex := strings.LastIndex(g.mainSCMDir, "/worktrees/")
 
 	// in submodules, the path looks like this: gitdir: ../.git/modules/test-submodule
 	// we need the parent folder to detect where the real .git folder is
-	if isSubmodule {
+	if strings.Contains(g.mainSCMDir, "/modules/") {
 		g.scmDir = resolveGitPath(gitdir.ParentFolder, g.mainSCMDir)
 		// this might be both a worktree and a submodule, where the path would look like
 		// this: path/.git/modules/module/path/worktrees/location. We cannot distinguish
 		// between worktree and a module path containing the word 'worktree,' however.
-		ind = strings.LastIndex(g.scmDir, "/worktrees/")
-		if ind > -1 && g.env.HasFilesInDir(g.scmDir, "gitdir") {
+		worktreeIndex = strings.LastIndex(g.scmDir, "/worktrees/")
+		if worktreeIndex > -1 && g.env.HasFilesInDir(g.scmDir, "gitdir") {
 			gitDir := filepath.Join(g.scmDir, "gitdir")
 			realGitFolder := g.env.FileContent(gitDir)
 			g.repoRootDir = strings.TrimSuffix(realGitFolder, ".git\n")
-			g.scmDir = g.scmDir[:ind]
+			g.scmDir = g.scmDir[:worktreeIndex]
 			g.mainSCMDir = g.scmDir
 			g.IsWorkTree = true
 			return true
@@ -469,6 +477,20 @@ func (g *Git) hasWorktree(gitdir *runtime.FileInfo) bool {
 		return true
 	}
 
+	// convert to absolute path for worktrees only
+	if strings.HasPrefix(g.mainSCMDir, "..") {
+		g.mainSCMDir = filepath.Join(gitdir.ParentFolder, g.mainSCMDir)
+	}
+
+	if worktreeIndex > -1 {
+		gitDir := filepath.Join(g.mainSCMDir, "gitdir")
+		g.scmDir = g.mainSCMDir[:worktreeIndex]
+		gitDirContent := g.env.FileContent(gitDir)
+		g.repoRootDir = strings.TrimSuffix(gitDirContent, ".git\n")
+		g.IsWorkTree = true
+		return true
+	}
+
 	// check for separate git folder(--separate-git-dir)
 	// check if the folder contains a HEAD file
 	if g.env.HasFilesInDir(g.mainSCMDir, "HEAD") {
@@ -531,10 +553,10 @@ func (g *Git) cleanUpstreamURL(url string) string {
 	}
 
 	// ssh://user@host.xz:1234/path/to/repo.git/
-	match = regex.FindNamedRegexMatch(`(ssh|ftp|git|rsync)://(.*@)?(?P<URL>[a-z0-9.]+)(:[0-9]{4})?/(?P<PATH>.*).git`, url)
+	match = regex.FindNamedRegexMatch(`(ssh|ftp|git|rsync)://(.*@)?(?P<URL>[a-z0-9.-]+)(:[0-9]{4})?/(?P<PATH>.*).git`, url)
 	if len(match) == 0 {
 		// host.xz:/path/to/repo.git/
-		match = regex.FindNamedRegexMatch(`^(?P<URL>[a-z0-9./]+):(?P<PATH>[a-z0-9./]+)$`, url)
+		match = regex.FindNamedRegexMatch(`^(?P<URL>[a-z0-9.-]+):(?P<PATH>[\w.\-~/@]+)$`, url)
 	}
 
 	if len(match) != 0 {
@@ -563,6 +585,7 @@ func (g *Git) getUpstreamIcon() string {
 	if len(g.RawUpstreamURL) == 0 {
 		return ""
 	}
+
 	g.UpstreamURL = g.cleanUpstreamURL(g.RawUpstreamURL)
 
 	// allow overrides first
@@ -642,7 +665,7 @@ func (g *Git) setGitStatus() {
 	}
 
 	output := g.getGitCommandOutput(args...)
-	for _, line := range strings.Split(output, "\n") {
+	for line := range strings.SplitSeq(output, "\n") {
 		if strings.HasPrefix(line, HASH) && len(line) >= len(HASH)+7 {
 			g.ShortHash = line[len(HASH) : len(HASH)+7]
 			g.Hash = line[len(HASH):]
@@ -679,11 +702,16 @@ func (g *Git) setGitStatus() {
 }
 
 func (g *Git) getGitCommandOutput(args ...string) string {
+	if len(g.command) == 0 {
+		return ""
+	}
+
 	args = append([]string{"-C", g.repoRootDir, "--no-optional-locks", "-c", "core.quotepath=false", "-c", "color.status=false"}, args...)
 	val, err := g.env.RunCommand(g.command, args...)
 	if err != nil {
 		return ""
 	}
+
 	return val
 }
 
@@ -691,7 +719,7 @@ func (g *Git) setGitHEADContext() {
 	branchIcon := g.props.GetString(BranchIcon, "\uE0A0")
 	if g.Ref == DETACHED {
 		g.Detached = true
-		g.setPrettyHEADName()
+		g.setHEADName()
 	} else {
 		head := g.formatBranch(g.Ref)
 		g.HEAD = fmt.Sprintf("%s%s", branchIcon, head)
@@ -706,7 +734,7 @@ func (g *Git) setGitHEADContext() {
 
 	getPrettyNameOrigin := func(file string) string {
 		var origin string
-		head := g.FileContents(g.mainSCMDir, file)
+		head := g.fileContent(g.mainSCMDir, file)
 		if head == "detached HEAD" {
 			origin = formatDetached()
 		} else {
@@ -717,7 +745,7 @@ func (g *Git) setGitHEADContext() {
 	}
 
 	parseInt := func(file string) int {
-		val, _ := strconv.Atoi(g.FileContents(g.mainSCMDir, file))
+		val, _ := strconv.Atoi(g.fileContent(g.mainSCMDir, file))
 		return val
 	}
 
@@ -762,7 +790,7 @@ func (g *Git) setGitHEADContext() {
 	if g.hasGitFile("MERGE_MSG") {
 		g.Merge = true
 		icon := g.props.GetString(MergeIcon, "\uE727 ")
-		mergeContext := g.FileContents(g.mainSCMDir, "MERGE_MSG")
+		mergeContext := g.fileContent(g.mainSCMDir, "MERGE_MSG")
 		matches := regex.FindNamedRegexMatch(`Merge (remote-tracking )?(?P<type>branch|commit|tag) '(?P<theirs>.*)'`, mergeContext)
 		// head := g.getGitRefFileSymbolicName("ORIG_HEAD")
 		if matches != nil && matches["theirs"] != "" {
@@ -790,7 +818,7 @@ func (g *Git) setGitHEADContext() {
 	// the todo file.
 	if g.hasGitFile("CHERRY_PICK_HEAD") {
 		g.CherryPick = true
-		sha := g.FileContents(g.mainSCMDir, "CHERRY_PICK_HEAD")
+		sha := g.fileContent(g.mainSCMDir, "CHERRY_PICK_HEAD")
 		cherry := g.props.GetString(CherryPickIcon, "\uE29B ")
 		g.HEAD = fmt.Sprintf("%s%s%s onto %s", cherry, commitIcon, g.formatSHA(sha), formatDetached())
 		return
@@ -798,14 +826,14 @@ func (g *Git) setGitHEADContext() {
 
 	if g.hasGitFile("REVERT_HEAD") {
 		g.Revert = true
-		sha := g.FileContents(g.mainSCMDir, "REVERT_HEAD")
+		sha := g.fileContent(g.mainSCMDir, "REVERT_HEAD")
 		revert := g.props.GetString(RevertIcon, "\uF0E2 ")
 		g.HEAD = fmt.Sprintf("%s%s%s onto %s", revert, commitIcon, g.formatSHA(sha), formatDetached())
 		return
 	}
 
 	if g.hasGitFile("sequencer/todo") {
-		todo := g.FileContents(g.mainSCMDir, "sequencer/todo")
+		todo := g.fileContent(g.mainSCMDir, "sequencer/todo")
 		matches := regex.FindNamedRegexMatch(`^(?P<action>p|pick|revert)\s+(?P<sha>\S+)`, todo)
 		if matches != nil && matches["sha"] != "" {
 			action := matches["action"]
@@ -840,17 +868,17 @@ func (g *Git) hasGitFile(file string) bool {
 }
 
 func (g *Git) getGitRefFileSymbolicName(refFile string) string {
-	ref := g.FileContents(g.mainSCMDir, refFile)
+	ref := g.fileContent(g.mainSCMDir, refFile)
 	return g.getGitCommandOutput("name-rev", "--name-only", "--exclude=tags/*", ref)
 }
 
-func (g *Git) setPrettyHEADName() {
+func (g *Git) setHEADName() {
 	// we didn't fetch status, fallback to parsing the HEAD file
 	if len(g.ShortHash) == 0 {
-		HEADRef := g.FileContents(g.mainSCMDir, "HEAD")
+		HEADRef := g.fileContent(g.mainSCMDir, "HEAD")
 		g.Detached = !strings.HasPrefix(HEADRef, "ref:")
-		if strings.HasPrefix(HEADRef, BRANCHPREFIX) {
-			branchName := strings.TrimPrefix(HEADRef, BRANCHPREFIX)
+		if after, ok := strings.CutPrefix(HEADRef, BRANCHPREFIX); ok {
+			branchName := after
 			g.Ref = branchName
 			g.HEAD = fmt.Sprintf("%s%s", g.props.GetString(BranchIcon, "\uE0A0"), g.formatBranch(branchName))
 			return
@@ -884,16 +912,21 @@ func (g *Git) WorktreeCount() int {
 	if g.worktreeCount > 0 {
 		return g.worktreeCount
 	}
-	if !g.env.HasFolder(g.scmDir + "/worktrees") {
+
+	worktreesFolder := filepath.Join(g.mainSCMDir, "worktrees")
+
+	if !g.env.HasFolder(worktreesFolder) {
 		return 0
 	}
-	worktreeFolders := g.env.LsDir(g.scmDir + "/worktrees")
+
+	worktreeFolders := g.env.LsDir(worktreesFolder)
 	var count int
 	for _, folder := range worktreeFolders {
 		if folder.IsDir() {
 			count++
 		}
 	}
+
 	return count
 }
 
@@ -902,14 +935,18 @@ func (g *Git) getRemoteURL() string {
 	if len(upstream) == 0 {
 		upstream = "origin"
 	}
+
 	cfg, err := ini.Load(g.scmDir + "/config")
 	if err != nil {
 		return g.getGitCommandOutput("remote", "get-url", upstream)
 	}
+
 	url := cfg.Section("remote \"" + upstream + "\"").Key("url").String()
 	if len(url) != 0 {
+		log.Debug("remote url found in config:", url)
 		return url
 	}
+
 	return g.getGitCommandOutput("remote", "get-url", upstream)
 }
 
